# -*- coding: utf-8 -*-

import json
import requests

class BaseApi:
    PAGE_SIZE = 50

    def __init__(self, config):
        self._config = config

    @property
    def version(self):
        return 'v1beta1'

    def headers(self):
        return {
            'X-Ab-Authorization': self._config.api_key,
            'Content-Type': 'application/json',
            'User-Agent': 'Armorblox-Python-SDK/' + self._config.sdk_version
        }

    def endpoint(self, path: str, api_version: str = None) -> str:
        if api_version is None:
            api_version = self.version
        return self._config.base_api_url.format(api_version) + path

    def list_params(self):
        return {
            'page_size': self.PAGE_SIZE,
            'page_token': '0',
        }

    def list_resource(self, path: str, headers: dict = None,
                      params: dict = None, options: dict = None):
        """

        Args:
            path: str
            headers: dict
            params: dict
            options: dict

        Raises:
            Exception:
        """
        h = self.headers()
        if headers is not None:
            h.update(headers)
        p = self.list_params()
        if params is not None:
            p.update(params)
            # Cap page size to PAGE_SIZE value for optimal performance
            p["page_size"] = min(p["page_size"], self.PAGE_SIZE)
        if options is None:
            options = {}
        response = requests.get(self.endpoint(path, options.get('api_version')),
                                headers=h, params=p)
        if response.status_code == 200:
            return response.json(), None
        else:
            return None, response
    
    def get_resource(self, path: str, resource_id: str, headers: dict = None,
                     params: dict = None, options: dict = None):
        """

        Args:
            path: str
            resource_id: str
            headers: dict
            params: dict
            options: dict
        Raises:
            Exception:
        """
        h = self.headers()
        if headers is not None:
            h.update(headers)
        if options is None:
            options = {}

        url = self.endpoint(path, options.get('api_version'))
        # ':' indicates that this is a tenant-scoped call and not a resource-scoped one
        if resource_id.startswith(':'):
            url = f"{url.rstrip('/')}{resource_id}"
        else:
            url = f"{url}/{resource_id}"

        response = requests.get(url, headers=h, params=params)

        if response.status_code == 200:
            return response.json()
        else:
            return {}


    def update_resource(self, path: str, resource_id: str, headers: dict = None,
                     params: dict = None, options: dict = None, body: dict = None):
        """

        Args:
            path: str
            resource_id: str
            headers: dict
            params: dict
            options: dict
            body: dict

        Raises:
            Exception:
        """
        h = self.headers()
        if headers is not None:
            h.update(headers)
        if options is None:
            options = {}

        url = self.endpoint(path, options.get('api_version')) + f"/{resource_id}"
        response = requests.patch(url, headers=h, params=params, data=json.dumps(body))
        if response.status_code == 200:
            return response.json(), None
        else:
            return None, response


# -*- coding: utf-8 -*-


from armorblox.config import Config
from armorblox.api.incidents_api import IncidentsApi, ThreatsApi, DLPIncidentsApi, AbuseIncidentsApi
from cached_property import cached_property


class Client:

    @staticmethod
    def sdk_version():
        return '0.1.0.20220201'

    def __init__(self, api_key: str, instance_name: str = None, instance_url: str = None):
        self.config = Config(api_key,
                             instance_name=instance_name,
                             instance_url=instance_url,
                             sdk_version=self.sdk_version())

    @cached_property
    def incidents(self):
        return IncidentsApi(self.config)

    @cached_property
    def threats(self):
        return ThreatsApi(self.config)

    @cached_property
    def dlp_incidents(self):
        return DLPIncidentsApi(self.config)

    @cached_property
    def abuse_incidents(self):
        return AbuseIncidentsApi(self.config)



# -*- coding: utf-8 -*-


from urllib.parse import urlparse


class Config:
    BASE_INSTANCE_URL = 'https://{}.armorblox.io/'
    BASE_API_PATH = 'api/{}/organizations/{}/'

    def __init__(
            self, api_key: str, instance_name: str = None, instance_url: str = None,
            sdk_version: str = 'Unspecified'):
        """

        Args:
            api_key: string
            instance_name: string
            instance_url: string
            sdk_version: string

        Raises:
            Exception:
        """
        self._sdk_version = sdk_version
        self._api_key = api_key
        if instance_url:
            self._instance_url = instance_url
            if not instance_url.endswith('/'):
                self._instance_url += '/'
            if instance_name:
                self._instance_name = instance_name
            else:
                self._instance_name = urlparse(instance_url).netloc.split('.')[0]
        elif instance_name:
            self._instance_url = self.BASE_INSTANCE_URL.format(instance_name)
            self._instance_name = instance_name
        else:
            raise Exception('At least one of instance_url or instance_name should be provided')
        self._base_api_url = self._instance_url + self.BASE_API_PATH.format('{}', self._instance_name)

    @property
    def sdk_version(self):
        return self._sdk_version

    @property
    def api_key(self):
        return self._api_key

    @property
    def instance_url(self):
        return self._instance_url

    @property
    def instance_name(self):
        return self._instance_name

    @property
    def base_api_url(self):
        return self._base_api_url



# -*- coding: utf-8 -*-


from armorblox.api.base_api import BaseApi
from enum import Enum, unique


@unique
class IncidentType(Enum):
    THREAT_INCIDENT_TYPE = 1
    DLP_INCIDENT_TYPE = 2
    ABUSE_INCIDENT_TYPE = 3


class IncidentsApi(BaseApi):
    PATH = 'incidents'
    TIME_FORMAT = '%Y-%m-%dT%H:%M:%SZ'

    def __init__(self, config, incident_type=None):
        super().__init__(config)
        self._incident_type = incident_type

    def list(self, page_token=None, params=None):
        if params is None:
            params = {
                'orderBy': 'DESC',
                'sortBy': 'DATE',
                'timeFilter': 'allTime'
            }
        if self._incident_type is not None:
            params['incidentTypesFilter'] = self._incident_type.name
        if page_token is not None:
            params['page_token'] = page_token

        response_json, response = self.list_resource(self.PATH, params=params)
        if response_json is None:
            return [], None, 0
        else:
            next_page_token = response_json.get('next_page_token', None)
            total_count = int(response_json.get('total_count', 0))
            incidents = response_json.get('incidents', [])
            return incidents, next_page_token, total_count

    def get(self, incident_id: int):
        params = {
            'pageSize': 20
        }

        return self.get_resource(self.PATH, str(incident_id), params=params)

    def analysis(self, incident_id: int):
        return self.get_resource(self.PATH, str(incident_id) + ':getAnalysis')

    def senders(self, incident_id: int):
        return self.get_resource(self.PATH, str(incident_id) + ':getSenders')

    def mail(self, object_id: str):
        params = {'objectId': object_id, 'objectType':'CONTENT_MAIL'}
        options = {'api_version': 'v1alpha1'}
        return self.get_resource('', ':getPolicyViolationDetailsByObjectId',
                                 params=params, options=options)

    def update(self, incident_id: int, body: dict):
        return self.update_resource(self.PATH, str(incident_id) + ':updateAction',
                                    body=body)


class ThreatsApi(IncidentsApi):
    def __init__(self, config):
        super().__init__(config, IncidentType.THREAT_INCIDENT_TYPE)


class DLPIncidentsApi(IncidentsApi):
    def __init__(self, config):
        super().__init__(config, IncidentType.DLP_INCIDENT_TYPE)


class AbuseIncidentsApi(IncidentsApi):
    def __init__(self, config):
        super().__init__(config, IncidentType.ABUSE_INCIDENT_TYPE)




# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['armorblox', 'armorblox.api']

package_data = \
{'': ['*']}

install_requires = \
['cached-property>=1.5.2,<2.0.0', 'requests>=2.27.1,<3.0.0']

setup_kwargs = {
    'name': 'armorblox-sdk',
    'version': '0.1.3',
    'description': 'Armorblox SDK for Python',
    'long_description': '<img src="https://assets.armorblox.com/f/52352/775x159/8fa6246e47/logo_color.svg" width=387 alt="Armorblox logo">\n\n# Armorblox Python SDK (Alpha)\n\n[![PyPI version](https://badge.fury.io/py/armorblox-sdk.svg)](https://badge.fury.io/py/armorblox-sdk)\n[![Apache-2 License](https://img.shields.io/badge/license-Apache2-blueviolet)](https://www.apache.org/licenses/LICENSE-2.0)\n\nThis is an alpha version of the SDK with limited documentation and no support.\n\n## Requirements\n\nPython 3.5+\n\n## Installation\n\n```\npip install armorblox-sdk\n```\n\n## Usage\n\n```\nfrom armorblox import client\n\n# Create an API client for your tenant\nc = client.Client(api_key=\'your-api-key-here\', instance_name=\'yourtenantname\')\n\n# Fetch information about an incident\'s analysis data\nincident_analysis = c.incidents.analysis(78143)\n\n# Fetch information about an incident\'s sender data\nincident_senders = c.incidents.senders(78143)\n\n# Fetch information about an object associated with an incident (usually mail). \n# Get the object ID from Get Incident by Id\'s response, under .events[].object_id\nincident_object = c.incidents.mail(\'d72c07bc789c30cb4d63d78ee2861f94add695f9c812e30cfb081b20d3e7e5e7\')\n\n# Updates the action to be taken for an incident\'s objects\nupdate_details = c.incidents.update(78143, body = {\n                  "policyActionType": "DELETE",\n                  "addSenderToException": False,\n                  "actionProfileId": ""\n                })\n\n\n# Fetch a list of threats\nthreat_incidents, next_page_token, total_incident_count = c.threats.list()\n\n# Fetch a specific threat\nincident = c.threats.get(44006)\n\n\n# Fetch a list of abuse incidents\nabuse_incidents, next_page_token, total_incident_count = c.abuse_incidents.list()\n\n# Fetch a specific abuse incident\nabuse_incident = c.abuse_incidents.get(44200)\n\n\n# Fetch a list of DLP incidents\ndlp_incidents, next_page_token, total_incident_count = c.dlp_incidents.list()\n\n# Fetch a specific DLP incident\ndlp_incident = c.dlp_incidents.get(44010)\n\n\n# Example to fetch all threats using next_page_token\nc = client.Client(api_key=\'your-api-key-here\', instance_name=\'yourtenantname\')\nnext_page_token = None\nincidents = []\nwhile True:\n    threats, next_page_token, total_incident_count = client.threats.list(page_token=next_page_token)\n    incidents.extend(threats)\n    if not next_page_token:\n        break\n```\n\n## Contributing\n\n* Install [Poetry](https://python-poetry.org)\n* Clone the SDK repo & `cd` into it\n```\ngit clone https://github.com/armorblox/armorblox-python-sdk\ncd armorblox-python-sdk\n```\n* Run `poetry install` to install the dependencies\n* Run `tox` to run the tests\n\n## Publishing\n\n#### TestPyPI\n\nOne-time setup\n```\npoetry config repositories.test-pypi https://test.pypi.org/legacy/\npoetry config pypi-token.test-pypi <your-TestPyPI-token>\n```\n\nPublishing\n```\npoetry publish --build -r test-pypi\n```\n\nUse\n```\npip install --index-url https://test.pypi.org/simple/ --no-deps armorblox-sdk\n```\nto make sure the installation works correctly.\n\n#### PyPI\n\nOne-time setup\n```\npoetry config pypi-token.pypi <your-PyPI-token>\n```\n\nPublishing\n```\npoetry publish --build\n```\n',
    'author': 'Rajat Upadhyaya',
    'author_email': '45485+urajat@users.noreply.github.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/armorblox/armorblox-python-sdk',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
